#
# spec file for package ghc-QuickCheck
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name QuickCheck
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.9.2
Release:        lp150.1.8
Summary:        Automatic testing of Haskell programs
License:        BSD-3-Clause
Group:          Development/Languages/Other
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-tf-random-devel
BuildRequires:  ghc-transformers-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with tests}
BuildRequires:  ghc-test-framework-devel
%endif

%description
QuickCheck is a library for random testing of program properties.

The programmer provides a specification of the program, in the form of
properties which functions should satisfy, and QuickCheck then tests that the
properties hold in a large number of randomly generated cases.

Specifications are expressed in Haskell, using combinators defined in the
QuickCheck library. QuickCheck provides combinators to define properties,
observe the distribution of test data, and define test data generators.

You can find a (slightly out-of-date but useful) manual at
<http://www.cse.chalmers.se/~rjmh/QuickCheck/manual.html>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE

%files devel -f %{name}-devel.files
%defattr(-,root,root,-)
%doc README changelog examples

%changelog
* Sun Feb 12 2017 psimons@suse.com
- Update to version 2.9.2 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 2.8.2 revision 0 with cabal2obs.
* Thu May 26 2016 mimi.vx@gmail.com
- update to 2.8.2
  * GHC 8 support
  * Add Arbitrary and CoArbitrary instances for types in containers package
  * Improve speed of shuffle combinator
  * Only print to stderr if it's a terminal.
  * Small changes: slightly improve documentation, remove redundant constraints
    from some functions' types, small improvements to Test.QuickCheck.All.
* Tue May 12 2015 mimi.vx@gmail.com
- update to 2.8.1
  * Fix bug where exceptions thrown printing counterexamples weren't
    being caught when terminal output was disabled
  * Don't export Test.QuickCheck.Property.result
  * Support for GHC 7.10
  * Arbitrary instance for Natural
  * New generators shuffle and sublistOf
  * Support for generic coarbitrary
  * When using the cover combinator, insufficient coverage now
    causes the property to fail
  * Test.QuickCheck.Function: new pattern synonym Fn
  * genericShrink no longer requires Typeable
  * Result has a new constructor InsufficientCoverage
  * resize throws an error if the size is negative
  * Fix memory leaks
  * Exceptions thrown by callbacks now cause the test to fail
  * Fixed a bug where the cover combinator wouldn't give a
    warning if coverage was 0%%
* Fri Apr 10 2015 mimi.vx@gmail.com
- update to 2.7.6
  * Add annotations for Safe Haskell.
  * Fix bug in cabal file which broke cabal test
  * Fixed bug - the Small modifier didn't work on unsigned types
  * Changed arbitrarySizedIntegral to have an Integral constraint
  instead of just Num
  * New genericShrink function provides generic shrinking with GHC.
  * New combinator x === y: fails if x /= y, but also prints their values
  * New function generate :: Gen a -> IO a for running a generator.
  * New combinators infiniteList and infiniteListOf for generating infinite lists.
  * Several combinators added to the main Test.QuickCheck module which
  were previously languishing in other modules. Of particular interest:
  quickCheckAll, ioProperty.
  * New combinators delay and capture which can be used (unsafely!)
  to reuse the random number seed. Useful for generating
  polymorphic (rank-2) values.
  * A new Discard data type and a Testable instance for discarding test cases.
  * All modifiers now have Functor instances and accessor functions.
  * Pressing ctrl-C during shrinking now shows the last failed
  test case, rather than the current shrinking candidate.
  * Experimental support for UHC. You will need the latest version of Cabal from git.
  * Better distribution of test data:
  * The Int generator now only generates fairly small numbers.
  * The new Small and Large modifiers control the distribution of integers
  (Small generates small numbers, Large from the whole range).
  * Floating-point numbers shrink better.
  * Improved random number generation:
  * QuickCheck now uses TFGen rather than StdGen on newer versions
  of GHC, because StdGen's random numbers aren't always random.
  * 'variant' now uses a prefix code. This should prevent some
  potential bananaskins with coarbitrary.
  * API changes:
  * The Gen monad now uses an abstract type QCGen rather than StdGen.
  * The Result type now returns the thrown exception and number
  of failed shrink attempts.
  * Property is now a newtype rather than Gen Prop as it was before.
  * promote is moved into the new module Test.QuickCheck.Gen.Unsafe.
  * 'printTestCase' is deprecated - its new name is 'counterexample'
  * 'morallyDubiousIOProperty' is deprecated - its new name is
  'ioProperty', no moral judgement involved :)
* Tue Sep  2 2014 peter.trommler@ohm-hochschule.de
- regenerate spec file
* Sat Aug 23 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- update to 2.6 from upstream
  * convenience instances for up to 7-tupels
  * stderr unbuffered
  * flag to say whether test case was interrupted
- BR ghc-extensible-exceptions-devel no longer required
- more transparent packaging (fewer macros)
* Mon Jan  7 2013 peter.trommler@ohm-hochschule.de
- expand macro in name tag to help source validator
* Sat Nov 17 2012 peter.trommler@ohm-hochschule.de
- make service localonly for Factory submission
* Tue Oct  2 2012 peter.trommler@ohm-hochschule.de
- update to 2.5.1.1 from upstream (no changelog)
- required by Haskell Platform 2012.4.0.0
* Sun Jun  3 2012 peter.trommler@ohm-hochschule.de
- update to 2.4.2 from upstream (no changelog)
- required by Haskell Platform 2012.2.0.0
* Thu Feb 23 2012 peter.trommler@ohm-hochschule.de
- Added BuildRoot for sle11-sp1
* Thu Dec 29 2011 peter.trommler@ohm-hochschule.de
- Enable hscolour
- Add rpmlinrc
* Mon Dec  5 2011 peter.trommler@ohm-hochschule.de
- Initial packaging.
